@@ -29,7 +29,7 @@ App::Music::ChordPro::Config - Configurator.
 
 This module first establishes a well-defined (builtin) configuration.
 
-Then it processes the config files specified by the envitronment and
+Then it processes the config files specified by the environment and
 adds the information to the global $config hash.
 
 The configurations files are 'relaxed' JSON files. This means that
@@ -1495,6 +1495,12 @@ sub default_config() {
 
     // For (debugging (internal use only)).
     "debug" : {
+        "config" : 0,
+        "fonts" : 0,
+        "images" : 0,
+        "layout" : 0,
+        "meta" : 0,
+        "mma" : 0,
         "spacing" : 0,
         "song" : 0,
   	"abc" : 0,
@@ -1527,6 +1533,7 @@ sub qd {
 }
 
 unless ( caller ) {
+    binmode STDOUT => ':utf8';
     print( default_config() );
     exit;
 }
